#
# spec file for package python-zc.buildout
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{!?license: %global license %doc}
Name:           python-zc.buildout
Version:        2.13.3
Release:        bp156.3.2
Summary:        System for managing development buildouts
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/zc.buildout
Source:         https://files.pythonhosted.org/packages/source/z/zc.buildout/zc.buildout-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 8.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Provides:       python-zc_buildout = %{version}
Obsoletes:      python-zc_buildout < %{version}
BuildArch:      noarch
# SECTION test requirements
# disabled because of unprovideable requirements and not shipped test files
#BuildRequires:  %%{python_module bobo}
#BuildRequires:  %%{python_module manuel}
#BuildRequires:  %%{python_module zc.recipe.deployment}
#BuildRequires:  %%{python_module zc.zdaemonrecipe}
#BuildRequires:  %%{python_module zdaemon}
#BuildRequires:  %%{python_module zope.testing}
# /SECTION
%python_subpackages

%description
System for managing development buildouts.

Buildout is a project designed to solve 2 problems:
 * Application-centric assembly and deployment
 * Repeatable assembly of programs from Python software distributions

%prep
%setup -q -n zc.buildout-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/zc/buildout
%python_expand %fdupes %{buildroot}%{$python_sitelib}/zc.buildout-2.9.5-py%{$python_version}.egg-info

#%%check
#%%python_exec setup.py test

%files %{python_files}
%doc README.rst CHANGES.rst COPYRIGHT.txt DEVELOPERS.txt
%license LICENSE.txt
%{python_sitelib}/*
%python3_only %{_bindir}/buildout

%changelog
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 2.13.3
  - Fix DeprecationWarning about MutableMapping.
  (`#484 <https://github.com/buildout/buildout/issues/484>`_)
* Sat Jul  6 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Uodate to version 2.13.2:
  - Fixed DeprecationWarning on python 3.7: "'U' mode is deprecated".
* Sat Feb 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.13.1:
  - Documentation update for the new ``buildout query`` command.
* Sun Jan 27 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.13.0:
  * Get information about the configuration with new command ``buildout query``.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Sep 17 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.12.2:
  - Upon an error, buildout exits with a non-zero exit code. This now also works
  when running with ``-D``.
  - Fixed most 'Deprecation' and 'Resource' warnings.
- update to version 2.12.1:
  - zc.buildout now explicitly requests zc.recipe.egg >=2.0.6 now.
* Sat Jul  7 2018 sebix+novell.com@sebix.at
- update to version 2.12.0:
  - Add a new buildout option ``allow-unknown-extras`` to enable
  installing requirements that specify extras that do not exist. This
  needs a corresponding update to zc.recipe.egg. See `issue 457
  <https://github.com/buildout/buildout/issues/457>`_.
  zc.recipe.egg has been updated to 2.0.6 for this change.
- update to version 2.11.5:
  - Fix for `issue 295 <https://github.com/buildout/buildout/issues/295>`_. On
  windows, deletion of temporary egg files is more robust now.
* Mon May 21 2018 sebix+novell.com@sebix.at
- update to version 2.11.4:
  - Fix for `issue 451 <https://github.com/buildout/buildout/issues/451>`:
  distributions with a version number that normalizes to a shorter version
  number (3.3.0 to 3.3, for instance) can be installed now.
* Sat Apr 14 2018 sebix+novell.com@sebix.at
- update to version 2.11.3:
  - Update to use the new PyPI at https://pypi.org/.
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- update to version 2.11.2:
  - Fix for the #442 issue: AttributeError on
  ``pkg_resources.SetuptoolsVersion``.
* Fri Mar  2 2018 sebix+novell.com@sebix.at
- update to version 2.11.1:
  - Made upgrade check more robust. When using extensions, the improvement
  introduced in 2.11 could prevent buildout from restarting itself when it
  upgraded setuptools.
* Sun Jan 21 2018 sebix+novell.com@sebix.at
- update to version 2.11.0:
  - Installed packages are added to the working set immediately. This helps in
  some corner cases that occur when system packages have versions that
  conflict with our specified versions.
- update to verion 2.10.0
  - Setuptools 38.2.0 started supporting wheels. Through setuptools, buildout
  now also supports wheels! You need at least version 38.2.3 to get proper
  namespace support.
  This setuptools change interfered with buildout's recent support for
  buildout.wheel <https://github.com/buildout/buildout.wheel>, resulting in
  a sudden "Wheels are not supported" error message (see issue 435
  <https://github.com/buildout/buildout/issues/425>). Fixed by making
  setuptools the default, though you can still use the buildout.wheel if you
  want.
- remove test boundary condition from specfile
* Fri Dec  1 2017 sebix+novell.com@sebix.at
- update to 2.9.6:
  * Fixed: could not install eggs when sdist file name and package name had different case.
* Sat Sep 23 2017 sebix+novell.com@sebix.at
- update to 2.9.5
  * Use HTTPS for PyPI's index.  PyPI redirects HTTP to HTTPS by default
  now so using HTTPS directly avoids the potential for that redirect
  being modified in flight.
* Sat Aug 19 2017 sebix+novell.com@sebix.at
- singlespec
- update to 2.9.4
- rename to python-zc.buildout
* Sun Sep 29 2013 p.drouand@gmail.com
- Update to version 2.2.1
  + distutils scripts: correct order of operations on from ... import
    lines (see https://github.com/buildout/buildout/issues/134).
  + Add an --allow-site-packges option to bootstrap.py, defaulting to False.
    If the value is false, strip any "site packages" (as defined by the
    site module) from sys.path before attempting to import setuptools / pkg_resources.
  + Updated the URL used to fetch ez_setup.py to the official,
    non-version- pinned version.
- Changes between version 2.2.0 and 2.1.0
  + Handle both addition and subtraction of elements (+= and -=) on
    the same key in the same section. Forward-ported from buildout 1.6.
  + Suppress the useless Link to <URL> ***BLOCKED*** by --allow-hosts error
    message being emitted by distribute / setuptools.
  + Extend distutils script generation to support module docstrings and
  _future__ imports.
  + Refactored picked versions logic to make it easier to use for plugins.
  + Use get_win_launcher API to find Windows launcher (falling back to resource
  _string for cli.exe).
  + Remove data_files from setup.py: it was installing README.txt in current
    directory during installation (merged from 1.x branch).
  + Switch dependency from distribute 0.6.x to setuptools 0.7.x.
- Use download url as source url
- Replace python-distribute with python-setuptools BuildRequires
- Add documentation from tarball
* Mon Mar 25 2013 alexandre@exatati.com.br
- Update to 2.1.0:
  - Meta-recipe support
  - Conditional sections
  - Buildout now accepts a --version command-line option to print
    its version.
  Fixed: Builout didn't exit with a non-zero exit status if there was a
    failure in combination with an upgrade.
  Fixed: We now fail with an informative error when an old bootstrap
    script causes buildout 2 to be used with setuptools.
  Fixed: An error incorrectly suggested that buildout 2 implemented all
    of the functionality of dumppickedversions.
  Fixed: Buildout generated bad scripts when no eggs needed to be added
    to sys.path.
  Fixed: Buildout didn't honour Unix umask when generating scripts.
    https://bugs.launchpad.net/zc.buildout/+bug/180705
  Fixed: update-versions-file didn't work unless
    show-picked-versions was also set.
    https://github.com/buildout/buildout/issues/71
* Thu Feb 21 2013 p.drouand@gmail.com
- Update to version 1.7.1:
  * Fixed: Constraints intended to prevent upgrading to
    buildout-2-compatible recipes weren't expressed correctly, leading to
    unintendional use of zc.recipe.egg-2.0.0a3.
- Update to version 1.7.0:
  * Unless version requirements are specified, buildout won't upgrade
    itself past version 1.
  * Versions in versions sections can now be simple constraints, like <2.0dev
    in addition to being simple versions.
  * This is used to prevent upgrading zc.recipe.egg and zc.recipe.testrunner
    past version 1.
  * If buildout is bootstrapped with a non-final release, it won't downgrade
    itself to a final release.
  * Fix: distribute 0.6.33 broke Python 2.4 compatibility
    remove data_files from setup.py, which was installing README.txt in
    current directory during installation [Domen Kožar]
    Windows fix: use cli-64.exe/cli.exe depending on 64/32 bit and try cli.exe
    if cli-64.exe is not found, fixing 9c6be7ac6d218f09e33725e07dccc4af74d8cf97
  * Windows fix: buildout init was broken, re.sub does not like a single backslash
  * fixed all builds on travis-ci
    use os._exit insted of sys.exit after ugrade forking
    Revert cfa0478937d16769c268bf51e60e69cd3ead50f3, it only broke a feature
* Tue Mar 13 2012 alexandre@exatati.com.br
- Regenerate spec file with py2pack.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Oct 13 2010 alexandre@exatati.com.br
- Update to 1.5.2.
* Mon Aug 30 2010 alexandre@exatati.com.br
- Update to 1.5.1.
* Wed Aug 25 2010 alexandre@exatati.com.br
- Update to 1.5.0.
* Fri Aug 20 2010 alexandre@exatati.com.br
- Update to 1.4.4.
* Sat May  1 2010 alexandre@exatati.com.br
- Update to 1.5.0b2.
* Mon Nov  2 2009 alexandre@exatati.com.br
- Update to 1.4.2.
* Fri Oct 16 2009 alexandre@exatati.com.br
- Initial package (1.4.1) for openSUSE.
